local atlas = {}

function atlas.startup()
  --Add our loaded images
  engine.assets = atlas.addBatch("ui", engine.assets, 96)
end

function atlas.addBatch(key, imgTable, maxSpriteSize)
  --Get the graphics canvas limits
  local grData = love.graphics.getSystemLimits()
  
  --Set the maximum texture size
  atlas.maxSize = math.ceil(grData.texturesize * .5)
  
  --Create the global texture atlas list
  if engine.texture_atlas == nil then
    engine.texture_atlas = {}
  end
  
  --Make a really big canvas
  engine.texture_atlas[key] = {
    canvas = love.graphics.newCanvas(atlas.maxSize, atlas.maxSize),
  }
  love.graphics.setCanvas(engine.texture_atlas[key].canvas)
  love.graphics.setColor(255,255,255,255)
  
  --Set coords at the bottom right corner of the image
  local x, y = -1, 1
  
  --Go through the asset table
  for k, v in pairs(imgTable) do
  
  --Draw each image to the canvas
    --Get the size of the image
    local w = imgTable[k]:getWidth()
    local h = imgTable[k]:getHeight()
    
    --Check we're not going off the edge
    if x - w - 1 > 0 then
      --Always subtract the extra 1 to ensure no texture bleed
      x = x - w - 1
    else
      x = atlas.maxSize - w
      y = y + 1
    end
    local py = atlas.maxSize - ((y * maxSpriteSize) + 1)
    --Draw the image
    love.graphics.draw(imgTable[k], x, py)
    
    --Remove the asset
    imgTable[k] = {}
  --Create a quad for each image
    imgTable[k].atlasKey = key
    imgTable[k].quad = love.graphics.newQuad(x, py, w, h, atlas.maxSize, atlas.maxSize)
    
  end
  love.graphics.setCanvas()
  return imgTable
end

return atlas