local heightSlider = engine.ui.slider:extend()
      function heightSlider:defineBounds()
        self:setLimits(1, 7, 1)
        self:setValue(4)
        self:setValue(engine.texture[engine.currentPlanetTexture][1].height)
      end
      function heightSlider:onValueChange()
        local cam = engine.system.chunk_camera
        engine.system.chunk_camera.octaves = self.value
        engine.system.chunk_camera.newMap(cam.tiles, cam.chunkWidth, cam.seed, cam.octaves)
        engine.system.chunk_camera.redraw = true
      end

local function newTerrainSlider(label, key, y, min, max, inc)
  local wid, hig = 290, 32
  local sl = engine.ui.slider:extend()
        function sl:defineBounds()
          self:setLimits(min, max, inc)
          self:setValue(min)
        end
        function sl:onValueChange()
          local cam = engine.system.chunk_camera
          engine.system.chunk_camera[key] = self.value
          engine.system.chunk_camera.newMap(cam.tiles, cam.chunkWidth, cam.seed, cam.octaves, cam.heightMap, cam.edges, cam.dropoff)
          engine.system.chunk_camera.redraw = true
        end
  return sl:new(label, 6, y, wid, hig, "standard_slider", "standard_slider", {255,255,255,255}, true)
end

local function newSlider(label, y, layer)
  local wid, hig = 290, 32
  local slider = engine.ui.slider:extend()
        function slider:defineBounds()
          self:setLimits(0, 255, 1)
          self:setValue(engine.texture[engine.currentPlanetTexture][layer].height)
        end
        function slider:onValueChange()
          local cam = engine.system.chunk_camera
          engine.system.chunk_camera.texture[layer].height = self.value
          engine.system.chunk_camera.newMap(cam.tiles, cam.chunkWidth, cam.seed, cam.octaves, cam.heightMap, cam.edges, cam.dropoff)
          engine.system.chunk_camera.redraw = true
        end
  return slider:new(label, 6, y, wid, hig, "standard_slider", "standard_slider", {255,255,255,255}, true)
end

local p = engine.ui.container:extend()
      
      function p:setup()
        local trans = {0,0,0,0}
        self:setSize(300, engine.screenHeight)
        self:setPosition(engine.screenWidth - self.w, 0)
        self:setBackground("standard_container")
        
        local y = 6
        self:add("height_label", engine.ui.label:new("Rough / Smooth", 6, y, self.w - 10, 16, trans, trans, {255,255,255,255}))
        y = y + self:stackUnder("height_label", 2)
        self:add("height_slider", heightSlider:new("Height", 6, y, self.w - 10, 32, "standard_slider", "standard_slider", {255,255,255,255}, true))
        y = y + self:stackUnder("height_slider", 2)
        for i = 1, #engine.system.chunk_camera.texture do
          local name = engine.system.chunk_camera.texture[i].name
          local label = engine.system.chunk_camera.texture[i].label
          self:add(name.."_label", engine.ui.label:new(label.." Level", 6, y, self.w - 10, 16, trans, trans, {255,255,255,255}))
          y = y + 18
          self:add(name, newSlider(label.." Slider", y, i))
          y = y + 34
        end
        
        self:add("heightMod_label", engine.ui.label:new("Height Modifier", 6, y, self.w - 10, 16, trans, trans, {255,255,255,255}))
        y = y + 18
        self:add("heightMod_slider", newTerrainSlider("HeightMod", "heightMod", y, 0.001, 0.5, .001))
        y = y + 34
        
        self:add("edges_label", engine.ui.label:new("Edge Modifier", 6, y, self.w - 10, 16, trans, trans, {255,255,255,255}))
        y = y + 18
        self:add("edges_slider", newTerrainSlider("EdgeMod", "edges", y, 0, 0.5, .01))
        y = y + 34
        
        self:add("dropoff_label", engine.ui.label:new("Dropoff Modifier", 6, y, self.w - 10, 16, trans, trans, {255,255,255,255}))
        y = y + 18
        self:add("dropoff_slider", newTerrainSlider("Dropoff", "dropoff", y, 0, 10, .1))
        y = y + 34
      end

return p